<?php

/**
 * @file
 * Contains the admin page and form
 */


/**
 * Admin page callback
 */
function node_quick_find_admin_page() {
  $count = variable_get('node_quick_find_number_of_blocks', 1);

  $headers = array(
    t('Id'),
    t('Block Title'),
    t('Operations'),
  );

  $rows = array();
  for ($i = 0; $i < $count; $i++) {
    $settings = variable_get('node_quick_find_'. $i, array());

    $title = db_result(db_query("SELECT title FROM {blocks} WHERE module = 'node_quick_find' AND delta = %d", $i));

    if (!$title) {
      $title = '<em>'. t('Not Set') .'</em>';
    }

    $ops = array(
      l(t('Edit'), 'admin/build/block/configure/node_quick_find/'. $i, array('query' => drupal_get_destination())),
    );

    $rows[] = array(
      $i,
      $title,
      implode(' | ', $ops),
    );
  }

  return theme('table', $headers, $rows);
}


/**
 * Admin form - currently only exposes the number of enabled blocks
 */
function node_quick_find_admin_form() {
  $form = array();

  $form['node_quick_find_number_of_blocks'] = array(
    '#type' => 'textfield',
    '#title' => t('Number Of Blocks'),
    '#description' => t('Enter the number of blocks you would like on your site.'),
    '#required' => TRUE,
    '#default_value' => variable_get('node_quick_find_number_of_blocks', 1),
    '#size' => 3,
    '#maxlength' => 3,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}


/**
 * Simple validate handler for the admin form
 */
function node_quick_find_admin_form_validate($form, &$form_state) {
  // Check for non-numeric characters
  if (preg_match('/[^0-9]/', $form_state['values']['node_quick_find_number_of_blocks'])) {
    form_set_error('node_quick_find_number_of_blocks', t('Please enter numeric values only'));
  }
  // Make sure the numeric value is more than 1
  elseif ($form_state['values']['node_quick_find_number_of_blocks'] < 1) {
    form_set_error('node_quick_find_number_of_blocks', t('The value must be more than 1'));
  }
}


/**
 * Submit handler for the admin form
 */
function node_quick_find_admin_form_submit($form, &$form_state) {
  // Save the number of blocks value
  variable_set('node_quick_find_number_of_blocks', $form_state['values']['node_quick_find_number_of_blocks']);

  // TODO... IF the value is less than the old value, should probably delete
  // old variables...

  // We need to rehash the blocks table to make sure any new blocks have entries.
  _block_rehash();

  drupal_set_message(t('Saved <em>Node Quick Find</em> Settings'));
}
